==> cxf-testutils-2.0.6.11-fuse-sources.jar: org/apache/locator/types/ListEndpointsResponse.java <==

package org.apache.locator.types;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.cxf.ws.addressing.EndpointReferenceType;
import org.apache.locator.types.ListEndpointsResponse.Endpoint;


/**
 * Output message element for "listEndpoints" operation.
 * 
 * <p>Java class for listEndpointsResponse element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="listEndpointsResponse">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="endpoint" maxOccurs="unbounded" minOccurs="0">
 *             &lt;complexType>
 *               &lt;complexContent>
 *                 &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                   &lt;sequence>
 *                     &lt;element name="endpoint_id" type="{http://apache.org/locator/types}EndpointIdentity"/>
 *                     &lt;element name="endpoint_reference" type="{http://www.w3.org/2005/08/addressing}EndpointReferenceType"/>
 *                   &lt;/sequence>
 *                 &lt;/restriction>
 *               &lt;/complexContent>
 *             &lt;/complexType>
 *           &lt;/element>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "endpoint"
})
@XmlRootElement(name = "listEndpointsResponse")
public class ListEndpointsResponse {

    @XmlElement(required = true)
    protected List<Endpoint> endpoint;

    /**
     * Gets the value of the endpoint property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the endpoint property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getEndpoint().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Endpoint }
     * 
     * 
     */
    public List<Endpoint> getEndpoint() {
        if (endpoint == null) {
            endpoint = new ArrayList<Endpoint>();
        }
        return this.endpoint;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="endpoint_id" type="{http://apache.org/locator/types}EndpointIdentity"/>
     *         &lt;element name="endpoint_reference" type="{http://www.w3.org/2005/08/addressing}EndpointReferenceType"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "endpointId",
        "endpointReference"
    })
    public static class Endpoint {

        @XmlElement(name = "endpoint_id", required = true)
        protected EndpointIdentity endpointId;
        @XmlElement(name = "endpoint_reference", required = true)
        protected EndpointReferenceType endpointReference;

        /**
         * Gets the value of the endpointId property.
         * 
         * @return
         *     possible object is
         *     {@link EndpointIdentity }
         *     
         */
        public EndpointIdentity getEndpointId() {
            return endpointId;
        }

        /**
         * Sets the value of the endpointId property.
         * 
         * @param value
         *     allowed object is
         *     {@link EndpointIdentity }
         *     
         */
        public void setEndpointId(EndpointIdentity value) {
            this.endpointId = value;
        }

        /**
         * Gets the value of the endpointReference property.
         * 
         * @return
         *     possible object is
         *     {@link EndpointReferenceType }
         *     
         */
        public EndpointReferenceType getEndpointReference() {
            return endpointReference;
        }

        /**
         * Sets the value of the endpointReference property.
         * 
         * @param value
         *     allowed object is
         *     {@link EndpointReferenceType }
         *     
         */
        public void setEndpointReference(EndpointReferenceType value) {
            this.endpointReference = value;
        }

    }

}

==> cxf-testutils-2.1.3.20-fuse-sources.jar: org/apache/locator/types/ListEndpointsResponse.java <==

package org.apache.locator.types;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.ws.wsaddressing.W3CEndpointReference;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="endpoint" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="endpoint_id" type="{http://apache.org/locator/types}EndpointIdentity"/>
 *                   &lt;element name="endpoint_reference" type="{http://www.w3.org/2005/08/addressing}EndpointReferenceType"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "endpoint"
})
@XmlRootElement(name = "listEndpointsResponse")
public class ListEndpointsResponse {

    protected List<ListEndpointsResponse.Endpoint> endpoint;

    /**
     * Gets the value of the endpoint property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the endpoint property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getEndpoint().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ListEndpointsResponse.Endpoint }
     * 
     * 
     */
    public List<ListEndpointsResponse.Endpoint> getEndpoint() {
        if (endpoint == null) {
            endpoint = new ArrayList<ListEndpointsResponse.Endpoint>();
        }
        return this.endpoint;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="endpoint_id" type="{http://apache.org/locator/types}EndpointIdentity"/>
     *         &lt;element name="endpoint_reference" type="{http://www.w3.org/2005/08/addressing}EndpointReferenceType"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "endpointId",
        "endpointReference"
    })
    public static class Endpoint {

        @XmlElement(name = "endpoint_id", required = true)
        protected EndpointIdentity endpointId;
        @XmlElement(name = "endpoint_reference", required = true)
        protected W3CEndpointReference endpointReference;

        /**
         * Gets the value of the endpointId property.
         * 
         * @return
         *     possible object is
         *     {@link EndpointIdentity }
         *     
         */
        public EndpointIdentity getEndpointId() {
            return endpointId;
        }

        /**
         * Sets the value of the endpointId property.
         * 
         * @param value
         *     allowed object is
         *     {@link EndpointIdentity }
         *     
         */
        public void setEndpointId(EndpointIdentity value) {
            this.endpointId = value;
        }

        /**
         * Gets the value of the endpointReference property.
         * 
         * @return
         *     possible object is
         *     {@link W3CEndpointReference }
         *     
         */
        public W3CEndpointReference getEndpointReference() {
            return endpointReference;
        }

        /**
         * Sets the value of the endpointReference property.
         * 
         * @param value
         *     allowed object is
         *     {@link W3CEndpointReference }
         *     
         */
        public void setEndpointReference(W3CEndpointReference value) {
            this.endpointReference = value;
        }

    }

}
